@@ -48,7 +48,7 @@ getCoefTemplate <- function(style){
 
 
 getSummary <- function(obj,alpha=.05,...) UseMethod("getSummary")
-setGeneric("getSummary")
+# setGeneric("getSummary")
 
 
 getSummary.lm <- function(obj,
@@ -1141,6 +1141,8 @@ getSummary.simex <- function(obj,
 ## Department of  Psychiatry and Behavioral Science
 ## Unversity of Washington
 
+getSummary.expcoef <- function(obj, alpha = 0.05, ...) UseMethod("getSummary.expcoef")
+
 getSummary.expcoef.glm <- function (obj, alpha = 0.05, ...)
 {
     smry <- summary(obj)
