@@ -301,7 +301,7 @@ int fillPorStreamBuf(porStreamBuf *b) {
   char *dummy = fgets((char *)b->buf,BUFSIZE,b->f);
   if(!dummy) {
       fseek(b->f,fpos,SEEK_SET);
-      int idummy = fread((char *)b->buf,1,BUFSIZE,b->f);
+      fread((char *)b->buf,1,BUFSIZE,b->f);
 
       error("cannot read from file at pos %d (fread result = <%s>)",fpos,b->buf);
   }
